<?php
/*
Plugin Name: لندین | Landin
Description: لندینگ پیج خود را با لندین بسازید و با استفاده از این افزونه صفحه فرود خود را به وردپرس متصل کنید.
Version: 1.0.2
Author: لندین
Author URI: https://landin.ir
License: GPL-2.0+
License URI: http://www.gnu.org/licenses/gpl-2.0.txt
*/

if (!defined('ABSPATH')) {
    exit;
}

// Add this function near the top of your file
function landin_enqueue_admin_scripts() {
    // Only load on our plugin page
    $screen = get_current_screen();
    if ($screen && strpos($screen->id, 'landin-landing-manager') !== false) {
        // Register and enqueue our script
        wp_register_script(
            'landin-admin-script',
            plugin_dir_url(__FILE__) . 'assets/admin.js',
            array('jquery'),
            '1.0.2',
            true
        );
        wp_enqueue_script('landin-admin-script');
        
        // Register and enqueue our styles
        wp_register_style(
            'landin-admin-style',
            plugin_dir_url(__FILE__) . 'assets/admin.css',
            array(),
            '1.0.2'
        );
        wp_enqueue_style('landin-admin-style');
    }
}
add_action('admin_enqueue_scripts', 'landin_enqueue_admin_scripts');

// بالا بردن زمان timeout
add_filter('http_request_args', function ($args) {
    // Set timeout to 30 seconds
    $args['timeout'] = 30;
    return $args;
}, 10, 1);
add_filter('http_request_timeout', function ($timeout) {
    return 30; // 30 seconds
});

// تنظیمات پیش‌فرض پلاگین
function landin_get_default_settings()
{
    return [
        'landing_base_path' => 'landings',
        'base_path_history' => ['landings'] // اضافه کردن تاریخچه مسیرها
    ];
}

function landin_init_filesystem()
{
    global $wp_filesystem;

    if (empty($wp_filesystem)) {
        require_once ABSPATH . '/wp-admin/includes/file.php';
        WP_Filesystem();
    }

    return $wp_filesystem;
}

// دریافت تنظیمات پلاگین
function landin_get_settings()
{
    $default_settings = landin_get_default_settings();
    $settings = get_option('landin_settings', $default_settings);
    return array_merge($default_settings, $settings);
}

function landin_get_upload_dir()
{
    $upload_dir = wp_upload_dir();
    $settings = landin_get_settings();
    $landing_dir = $upload_dir['basedir'] . '/' . $settings['landing_base_path'];
    if (!file_exists($landing_dir)) {
        wp_mkdir_p($landing_dir);
    }
    return $landing_dir;
}

function landin_register_rewrite_rules()
{
    $settings = landin_get_settings();
    $base_path = $settings['landing_base_path'];

    // حذف قوانین موجود با فلاش کردن
    global $wp_rewrite;
    $wp_rewrite->flush_rules(true);

    // افزودن قانون بازنویسی فقط برای مسیر فعلی صفحات لندینگ
    add_rewrite_rule(
        '^' . $base_path . '/([^/]+)/?$',
        'index.php?landin_slug=$matches[1]',
        'top'
    );
}

// منو مدیریت
add_action('admin_menu', function () {
    add_menu_page(
        'مدیریت لندینگ‌ها',
        'لندین',
        'manage_options',
        'landin-landing-manager',
        'landin_landing_page_admin',
        plugin_dir_url(__FILE__) . 'assets/icon.svg',
        30
    );
});

// محتوای صفحه مدیریت
function landin_landing_page_admin()
{
    if (isset($_GET['tab'])) {
        // For tab switching, verify nonce if available
        if (isset($_GET['_wpnonce']) && wp_verify_nonce(sanitize_key($_GET['_wpnonce']), 'landin_switch_tab')) {
            $active_tab = sanitize_text_field(wp_unslash($_GET['tab']));
        } else {
            // For direct URL access without nonce (initial page load)
            $active_tab = sanitize_text_field(wp_unslash($_GET['tab']));
        }
    } else {
        $active_tab = 'manage';
    }
    $landing_dir = landin_get_upload_dir();
    $settings = landin_get_settings();
?>
    <div class="wrap landin-admin-page">
        <h1 style="margin-top: 32px;">افزونه اتصال به لندین</h1>

        <!-- سیستم تب‌ها -->
        <div class="landin-tabs">
            <a href="?page=landin-landing-manager&tab=manage" class="landin-tab <?php echo $active_tab === 'manage' ? 'active' : ''; ?>">مدیریت صفحات</a>
            <a href="?page=landin-landing-manager&tab=settings" class="landin-tab <?php echo $active_tab === 'settings' ? 'active' : ''; ?>">تنظیمات اتصال</a>
            <a href="?page=landin-landing-manager&tab=help" class="landin-tab <?php echo $active_tab === 'help' ? 'active' : ''; ?>">راهنما</a>
        </div>

        <?php
        // محتوای تب‌ها
        if ($active_tab === 'manage') {
            landin_show_manage_tab($landing_dir, $settings);
        } elseif ($active_tab === 'settings') {
            landin_show_settings_tab();
        } else {
            landin_show_help_tab();
        }
        ?>
    </div>
<?php
}

// نمایش تب مدیریت صفحات
function landin_show_manage_tab($landing_dir, $settings)
{
    // بررسی درخواست حذف لندینگ
    if (
        isset($_SERVER['REQUEST_METHOD']) &&
        $_SERVER['REQUEST_METHOD'] === 'POST' &&
        current_user_can('manage_options') &&
        isset($_POST['action']) &&
        $_POST['action'] === 'delete_landing' &&
        !empty($_POST['landing_slug']) &&
        isset($_POST['landin_delete_nonce']) &&
        wp_verify_nonce(sanitize_key($_POST['landin_delete_nonce']), 'landin_delete_action')
    ) {
        $slug = sanitize_text_field(wp_unslash($_POST['landing_slug']));
        $base_path = isset($_POST['landing_base_path']) ?
            sanitize_text_field(wp_unslash($_POST['landing_base_path'])) :
            $settings['landing_base_path'];

        $upload_dir = wp_upload_dir();
        $target_dir = $upload_dir['basedir'] . '/' . $base_path . '/' . $slug;

        if (file_exists($target_dir) && is_dir($target_dir)) {
            // حذف دایرکتوری و محتویات آن
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator(
                    $target_dir,
                    RecursiveDirectoryIterator::SKIP_DOTS
                ),
                RecursiveIteratorIterator::CHILD_FIRST
            );
            foreach ($files as $fileinfo) {
                $todo = $fileinfo->isDir() ? 'rmdir' : 'unlink';
                $todo($fileinfo->getRealPath());
            }
            $wp_filesystem = landin_init_filesystem();
            $wp_filesystem->rmdir($target_dir, true);
            echo '<div class="notice notice-success is-dismissible"><p>لندینگ با موفقیت حذف شد.</p></div>';
        } else {
            echo '<div class="notice notice-error is-dismissible"><p>لندینگ مورد نظر یافت نشد.</p></div>';
        }
    }

   // بررسی آپلود فایل
    if (
        isset($_SERVER['REQUEST_METHOD']) &&
        $_SERVER['REQUEST_METHOD'] === 'POST' &&
        current_user_can('manage_options') &&
        isset($_POST['landin_upload_nonce']) &&
        wp_verify_nonce(sanitize_key($_POST['landin_upload_nonce']), 'landin_upload_action') &&
        !empty($_POST['landing_slug'])
    ) {
        // Validate file upload
        if (
            !empty($_FILES) &&
            isset($_FILES['landing_file']) &&
            isset($_FILES['landing_file']['tmp_name']) &&
            !empty($_FILES['landing_file']['tmp_name'])
        ) {
            // Sanitize the uploaded file
            $uploaded_file = array();
            $uploaded_file['name'] = isset($_FILES['landing_file']['name']) ? sanitize_file_name($_FILES['landing_file']['name']) : '';
            $uploaded_file['type'] = isset($_FILES['landing_file']['type']) ? sanitize_text_field($_FILES['landing_file']['type']) : '';
            $uploaded_file['tmp_name'] = isset($_FILES['landing_file']['tmp_name']) ? sanitize_text_field($_FILES['landing_file']['tmp_name']) : '';
            $uploaded_file['error'] = isset($_FILES['landing_file']['error']) ? intval($_FILES['landing_file']['error']) : 0;
            $uploaded_file['size'] = isset($_FILES['landing_file']['size']) ? intval($_FILES['landing_file']['size']) : 0;

            // Then use $uploaded_file instead of $_FILES['landing_file']
            $slug = sanitize_title(wp_unslash($_POST['landing_slug']));
            $target_dir = $landing_dir . '/' . $slug;
            wp_mkdir_p($target_dir);

            // Use the sanitized uploaded file data
            $file_ext = pathinfo($uploaded_file['name'], PATHINFO_EXTENSION);

            if (strtolower($file_ext) === 'html') {
                $target_path = $target_dir . '/index.html';

                $wp_filesystem = landin_init_filesystem();
                $file_content = file_get_contents($uploaded_file['tmp_name']);

                if ($wp_filesystem->put_contents($target_path, $file_content, FS_CHMOD_FILE)) {
                    // به‌روزرسانی قوانین بازنویسی پس از اضافه کردن لندینگ جدید
                    flush_rewrite_rules();
                    echo '<div class="notice notice-success is-dismissible"><p>فایل HTML با موفقیت آپلود شد.</p></div>';
                } else {
                    echo '<div class="notice notice-error is-dismissible"><p>خطا در آپلود فایل.</p></div>';
                }
            } else {
                echo '<div class="notice notice-error is-dismissible"><p>لطفا فقط فایل HTML آپلود کنید.</p></div>';
            }
        }
    }

?>
    <!-- طرح‌بندی دو ستونه در تب "مدیریت صفحات" -->
    <div class="landin-manage-layout">
        <div class="landin-form-column">
            <div class="landin-form">
                <form method="post" enctype="multipart/form-data">
                    <?php wp_nonce_field('landin_upload_action', 'landin_upload_nonce'); ?>
                    <div class="form-group">
                        <label for="landing-slug">آدرس دلخواه صفحه (مثلا: nowruz)</label>
                        <input type="text" id="landing-slug" name="landing_slug" required placeholder="مثال: my-landing-page">
                    </div>

                    <div class="form-group">
                        <label for="landing-file">فایل اسکریپت اتصال :</label>
                        <div class="landin-file-input">
                            <input type="file" id="landing-file" name="landing_file" accept=".html" required>
                            <span class="file-custom">انتخاب فایل HTML</span>
                        </div>
                    </div>

                    <button type="submit" class="submit-btn">بارگذاری</button>
                </form>
            </div>
        </div>

        <div class="landin-banner-column">
            <div class="landin-banner">
                <img
                    src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'assets/banner-background.png'); ?>"
                    alt="banner-background"
                    class="banner-background" />
                <div class="banner-right-side">
                    <p class="title">۷ روز رایگان از لندین استفاده کنید.</p>
                    <p>تنها در ۱۰ دقیقه یک صفحه فرود خود را با چند کلیک ساده بسازید.</p>
                    <a href="https://app.landin.ir" target="_blank" class="landin-banner-button"><span>ساخت صفحه فرود</span> <svg width="6" height="10" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <g clip-path="url(#prefix__clip0_1_19)">
                                <path d="M1.886 4.778L5.459 1.2a.524.524 0 000-.739L5.146.148a.523.523 0 00-.739 0L.152 4.403a.527.527 0 000 .742L4.403 9.4a.523.523 0 00.739 0l.313-.313a.523.523 0 000-.739l-3.569-3.57z" fill="#4A09F4" />
                            </g>
                            <defs>
                                <clipPath id="prefix__clip0_1_19">
                                    <path fill="#fff" d="M0 0h5.612v9.553H0z" />
                                </clipPath>
                            </defs>
                        </svg></a>
                </div>
                <div class="banner-left-side">
                    <img
                        src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'assets/banner-image.png'); ?>"
                        alt="banner-image"
                        class="banner-image" />
                </div>
            </div>
        </div>
    </div>

    <h2 class="landin-cards-heading">لندینگ‌های موجود</h2>
    <div class="landing-cards">
    <?php
    // همه لندیگ ها را از base_path_history و landing_base_path خوانده و نمایش داده شود  
    $upload_dir = wp_upload_dir();
    $all_landing_pages = [];

    // ابتدا مسیر پایه فعلی را بررسی کنید
    foreach (glob($landing_dir . '/*', GLOB_ONLYDIR) as $dir) {
        $slug = basename($dir);
        $all_landing_pages[$slug] = [
            'slug' => $slug,
            'path' => $dir,
            'base_path' => $settings['landing_base_path']
        ];
    }

    // اگر در مسیر فعلی یافت نشد، تمام مسیرهای تاریخی را بررسی کنید
    if (!empty($settings['base_path_history'])) {
        foreach ($settings['base_path_history'] as $history_path) {
            // اگر مسیر پایه فعلی است، آن را نادیده بگیرید
            if ($history_path === $settings['landing_base_path']) {
                continue;
            }

            $history_dir = $upload_dir['basedir'] . '/' . $history_path;
            if (file_exists($history_dir) && is_dir($history_dir)) {
                foreach (glob($history_dir . '/*', GLOB_ONLYDIR) as $dir) {
                    $slug = basename($dir);
                    // اگر لندینگ قبلاً اضافه نشده است، آن را اضافه کنید
                    if (!isset($all_landing_pages[$slug])) {
                        $all_landing_pages[$slug] = [
                            'slug' => $slug,
                            'path' => $dir,
                            'base_path' => $history_path
                        ];
                    }
                }
            }
        }
    }

    // Display all landing pages
    foreach ($all_landing_pages as $landing_info) {
        $slug = $landing_info['slug'];
        $base_path = $landing_info['base_path'];

        $url = home_url(
            '/' . $settings['landing_base_path'] . '/' . $slug . '/'
        ); // مسیر URL لندینگ با مسیر پایه فعلی

        $iframe_url = home_url(
            '/wp-content/uploads/' . $base_path . '/' . $slug . '/index.html'
        ); // لینک به فایل index.html لندینگ با مسیر اصلی آن

        echo '<div class="landing-card">';
        echo '<div class="card-content">';
        echo '<div class="iframe-container">';
        echo '<iframe src="' . esc_url($iframe_url) . '" frameborder="0" scrolling="no" allowfullscreen width="1200" height="800" style="transform: scale(0.25); transform-origin: 0 0; overflow: hidden;" sandbox="allow-same-origin allow-scripts"></iframe>';
        echo '</div>';

        // دکمه حذف
        echo '<form method="post" class="delete-landing-form">';
        wp_nonce_field('landin_delete_action', 'landin_delete_nonce');
        echo '<input type="hidden" name="action" value="delete_landing">';
        echo '<input type="hidden" name="landing_slug" value="' . esc_attr($slug) . '">';
        echo '<input type="hidden" name="landing_base_path" value="' . esc_attr($base_path) . '">';
        echo '<button type="submit" class="delete-landing-btn" onclick="return confirm(\'' . esc_js('آیا از حذف این لندینگ مطمئن هستید؟ این عمل غیرقابل بازگشت است.') . '\');"><svg width="7" height="3" viewBox="0 0 7 3" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M1 1.28711H6.07731" stroke="#FFFFFF" stroke-width="1.5" stroke-linecap="round"/></svg></button>';
        echo '</form>';

        // نمایش نام و مسیر پایه
        echo '<h3>' . esc_html($slug);

        // اگر مسیر پایه با مسیر فعلی متفاوت است، آن را نمایش دهیم
        if ($base_path !== $settings['landing_base_path']) {
            echo ' <span class="landing-path-badge">' . esc_html($base_path) . '</span>';
        }

        echo '</h3>';
        echo '<a href="' . esc_url($url) . '" target="_blank" class="button">مشاهده</a>';
        echo '</div>';
        echo '</div>';
    }
    echo '</div>';
}

// نمایش تب تنظیمات اتصال
function landin_show_settings_tab()
{
    $settings = landin_get_settings();

    // بررسی ذخیره تنظیمات
    if (
        isset($_SERVER['REQUEST_METHOD']) &&
        $_SERVER['REQUEST_METHOD'] === 'POST' &&
        current_user_can('manage_options') &&
        isset($_POST['landin_settings_submit']) &&
        isset($_POST['landin_settings_nonce']) &&
        wp_verify_nonce(sanitize_key($_POST['landin_settings_nonce']), 'landin_settings_action')
    ) {
        $new_base_path = isset($_POST['landing_base_path']) ? sanitize_text_field(wp_unslash($_POST['landing_base_path'])) : $settings['landing_base_path'];
        $old_base_path = $settings['landing_base_path'];
        
        // فقط در صورتی ادامه دهید که مسیر واقعاً تغییر کرده باشد
        if ($old_base_path !== $new_base_path) {
            $upload_dir = wp_upload_dir();
            $old_dir = $upload_dir['basedir'] . '/' . $old_base_path;
            $new_dir = $upload_dir['basedir'] . '/' . $new_base_path;

            // اگر دایرکتوری جدید وجود ندارد، آن را ایجاد کنید
            if (!file_exists($new_dir)) {
                wp_mkdir_p($new_dir);
            }

            // انتقال تمام صفحات لندینگ از دایرکتوری قدیمی به دایرکتوری جدید
            $success = true;
            if (file_exists($old_dir) && is_dir($old_dir)) {
                // دریافت تمام زیرپوشه‌ها در دایرکتوری لندینگ قدیمی
                $folders = glob($old_dir . '/*', GLOB_ONLYDIR);

                foreach ($folders as $folder) {
                    $slug = basename($folder);
                    $new_folder = $new_dir . '/' . $slug;

                    // ایجاد دایرکتوری مقصد
                    if (!file_exists($new_folder)) {
                        wp_mkdir_p($new_folder);
                    }

                    // انتقال تمام فایل‌ها از دایرکتوری قدیمی به دایرکتوری جدید
                    $files = glob($folder . '/*');
                    foreach ($files as $file) {
                        $file_name = basename($file);
                        $new_file_path = $new_folder . '/' . $file_name;

                        // کپی فایل به مکان جدید
                        if (!copy($file, $new_file_path)) {
                            $success = false;
                            break 2; // خروج از هر دو حلقه اگر کپی ناموفق باشد
                        }

                        // حذف فایل اصلی
                        $wp_filesystem = landin_init_filesystem();
                        $wp_filesystem->delete($file);
                    }

                    // حذف دایرکتوری قدیمی پس از انتقال فایل‌ها
                    $wp_filesystem = landin_init_filesystem();
                    $wp_filesystem->rmdir($folder, true);
                }

                // حذف دایرکتوری پایه قدیمی اگر خالی است
                if (count(glob($old_dir . '/*')) === 0) {
                    $wp_filesystem = landin_init_filesystem();
                    $wp_filesystem->rmdir($old_dir, true);
                }
            }

            if ($success) {
                // Save new settings
                $current_history = isset($settings['base_path_history']) ? $settings['base_path_history'] : [];

                // Add new path to history if it doesn't already exist
                if (!in_array($new_base_path, $current_history)) {
                    $current_history[] = $new_base_path;
                }

                $new_settings = [
                    'landing_base_path' => $new_base_path,
                    'base_path_history' => $current_history
                ];

                // In landin_show_settings_tab function, after updating settings:
                update_option('landin_settings', $new_settings);

                // ثبت مجدد قوانین بازنویسی با مسیر جدید
                landin_register_rewrite_rules();

                // Force flush rewrite rules
                flush_rewrite_rules(true);

                echo '<div class="notice notice-success is-dismissible"><p>تنظیمات با موفقیت ذخیره شدند و فایل‌های لندینگ به مسیر جدید منتقل شدند.</p></div>';
            } else {
                echo '<div class="notice notice-error is-dismissible"><p>خطا در انتقال فایل‌ها. لطفا مجدداً تلاش کنید یا با پشتیبانی تماس بگیرید.</p></div>';
            }

            // Update local settings
            $settings = landin_get_settings();
        } else {
            // If base path hasn't changed, just save settings
            $current_history = isset($settings['base_path_history']) ? $settings['base_path_history'] : [];

            // Add new path to history if it doesn't already exist
            if (!in_array($new_base_path, $current_history)) {
                $current_history[] = $new_base_path;
            }

            $new_settings = [
                'landing_base_path' => $new_base_path,
                'base_path_history' => $current_history
            ];

            update_option('landin_settings', $new_settings);

            landin_register_rewrite_rules();

            flush_rewrite_rules(true);

            echo '<div class="notice notice-success is-dismissible"><p>تنظیمات با موفقیت ذخیره شدند.</p></div>';

            // Update local settings
            $settings = landin_get_settings();
        }
    }

    // بررسی انتخاب مسیر از تاریخچه
    if (
        isset($_SERVER['REQUEST_METHOD']) &&
        $_SERVER['REQUEST_METHOD'] === 'POST' &&
        current_user_can('manage_options') &&
        isset($_POST['select_from_history']) &&
        isset($_POST['history_path']) &&
        isset($_POST['landin_history_nonce']) &&
        wp_verify_nonce(sanitize_key($_POST['landin_history_nonce']), 'landin_history_action')
    ) {
        $selected_path = sanitize_text_field(wp_unslash($_POST['history_path']));
        $current_history = isset($settings['base_path_history']) ? $settings['base_path_history'] : [];

        if (in_array($selected_path, $current_history)) {
            $old_base_path = $settings['landing_base_path'];

            // Only proceed with file moving if the path has actually changed
            if ($old_base_path !== $selected_path) {
                $upload_dir = wp_upload_dir();
                $old_dir = $upload_dir['basedir'] . '/' . $old_base_path;
                $new_dir = $upload_dir['basedir'] . '/' . $selected_path;

                // Create the new directory if it doesn't exist
                if (!file_exists($new_dir)) {
                    wp_mkdir_p($new_dir);
                }

                // Move all landing pages from old directory to new directory
                $success = true;
                if (file_exists($old_dir) && is_dir($old_dir)) {
                    // Get all subfolders in the old landing directory
                    $folders = glob($old_dir . '/*', GLOB_ONLYDIR);

                    foreach ($folders as $folder) {
                        $slug = basename($folder);
                        $new_folder = $new_dir . '/' . $slug;

                        // Create destination directory
                        if (!file_exists($new_folder)) {
                            wp_mkdir_p($new_folder);
                        }

                        // Move all files from old directory to new directory
                        $files = glob($folder . '/*');
                        foreach ($files as $file) {
                            $file_name = basename($file);
                            $new_file_path = $new_folder . '/' . $file_name;

                            // Copy the file to new location
                            if (!copy($file, $new_file_path)) {
                                $success = false;
                                break 2; // Exit both loops if copy fails
                            }

                            // Delete the original file
                            $wp_filesystem = landin_init_filesystem();
                            $wp_filesystem->delete($file);
                        }

                        // Remove the old directory after files have been moved
                        $wp_filesystem = landin_init_filesystem();
                        $wp_filesystem->rmdir($folder, true);
                    }

                    // Remove the old base directory if it's empty
                    if (count(glob($old_dir . '/*')) === 0) {
                        $wp_filesystem = landin_init_filesystem();
                        $wp_filesystem->rmdir($old_dir, true);
                    }
                }

                if ($success) {
                    // Save new settings
                    $new_settings = $settings;
                    $new_settings['landing_base_path'] = $selected_path;

                    update_option('landin_settings', $new_settings);

                    // Re-register rewrite rules with the new path
                    landin_register_rewrite_rules();

                    // Force flush rewrite rules
                    flush_rewrite_rules(true);

                    echo '<div class="notice notice-success is-dismissible"><p>مسیر پایه به "<strong>' . esc_html($selected_path) . '</strong>" تغییر یافت و فایل‌های لندینگ به مسیر جدید منتقل شدند.</p></div>';
                } else {
                    echo '<div class="notice notice-error is-dismissible"><p>خطا در انتقال فایل‌ها. لطفا مجدداً تلاش کنید یا با پشتیبانی تماس بگیرید.</p></div>';
                }
            } else {
                // If base path hasn't changed, just save settings
                $new_settings = $settings;
                $new_settings['landing_base_path'] = $selected_path;

                update_option('landin_settings', $new_settings);

                // Re-register rewrite rules with the new path
                landin_register_rewrite_rules();

                // Force flush rewrite rules
                flush_rewrite_rules(true);

                echo '<div class="notice notice-success is-dismissible"><p>مسیر پایه به "<strong>' . esc_html($selected_path) . '</strong>" تغییر یافت.</p></div>';
            }

            // Update local settings
            $settings = landin_get_settings();
        }
    }

    echo '<div class="landin-form settings-form">';

    // نمایش تاریخچه مسیرها
    if (!empty($settings['base_path_history']) && count($settings['base_path_history']) > 1) {
        echo '<div class="landin-history-section">';
        echo '<h3>تاریخچه مسیرهای پایه قبلی</h3>';
        echo '<p class="description">برای استفاده مجدد از مسیرهای قبلی، یکی را انتخاب کنید:</p>';

        echo '<form method="post" class="history-form">';
        wp_nonce_field('landin_history_action', 'landin_history_nonce');
        echo '<div class="history-select-container">';
        echo '<select name="history_path" class="history-select">';

        foreach ($settings['base_path_history'] as $path) {
            $selected = ($path === $settings['landing_base_path']) ? 'selected' : '';
            echo '<option value="' . esc_attr($path) . '" ' . esc_attr($selected) . '>' . esc_html($path) . '</option>';
        }

        echo '</select>';
        echo '<button type="submit" name="select_from_history" class="history-select-btn">انتخاب</button>';
        echo '</div>';
        echo '</form>';
        echo '</div>';
    }

    // فرم تنظیمات اصلی
    echo '<form method="post">';
    wp_nonce_field('landin_settings_action', 'landin_settings_nonce');

    echo '<div class="form-group">';
    echo '<label for="landing-base-path">مسیر پایه لندینگ‌ها:</label>';
    echo '<input type="text" id="landing-base-path" name="landing_base_path" value="' . esc_attr($settings['landing_base_path']) . '" required placeholder="مثال: landings">';
    echo '<p class="description">این مسیر در URL لندینگ‌های شما به صورت https://yourdomain.com/<span class="highlight">' . esc_html($settings['landing_base_path']) . '</span>/slug نمایش داده می‌شود.</p>';
    echo '</div>';

    echo '<input type="hidden" name="landin_settings_submit" value="1">';
    echo '<button type="submit" class="submit-btn">ذخیره تنظیمات</button>';
    echo '</form>';
    echo '</div>';
}

// نمایش تب راهنما
function landin_show_help_tab()
{
    echo '<div class="landin-help">';
    echo '<h2>راهنمای استفاده از افزونه اتصال لندینگ پیج لندین</h2>';

    echo '<div class="landin-help-section">';
    echo '<h3>مرحله اول: ساخت لندینگ‌پیج در لندین و دریافت اسکریپت</h3>';
    echo '<p>ابتدا در <span class="bold">لندین</span> ثبت‌نام کرده و لندینگ‌پیج موردنظر خود را ایجاد و منتشر کنید.</p>';
    echo 'پس از انتشار، وارد <span class="bold">پنل کاربری</span> خود در لندین شده و به بخش <span class="bold">صفحات</span>
    بروید. هر لندینگ‌پیج ایجادشده در این بخش دارای یک <span class="bold">کارت اختصاصی</span> است.';
    echo '<p>در نوار پایین تصویر لندینگ‌پیج، روی آیکون <code>&lt;/&gt;</code> که کنار دکمه‌های ویرایش (مداد) و مشاهده قرار دارد کلیک کنید تا اسکریپت اتصال آن صفحه دانلود شود.<p/>';
    $image_url = plugin_dir_url(__FILE__) . 'assets/help-image.png';
    $image_id = attachment_url_to_postid($image_url);
    
    if ($image_id) {
        // If the image is in the media library, use wp_get_attachment_image
        echo wp_get_attachment_image($image_id, 'full', false, array('class' => 'help-image', 'alt' => 'راهنمای استفاده از افزونه لندین'));
    } else {
        // For plugin bundled images that aren't in the media library
        $image_attr = array(
            'src' => esc_url($image_url),
            'class' => 'help-image',
            'alt' => 'راهنمای استفاده از افزونه لندین',
            'loading' => 'lazy',
        );
        
        // Properly escape attributes
        $attributes = '';
        foreach ($image_attr as $key => $value) {
            $attributes .= ' ' . esc_attr($key) . '="' . esc_attr($value) . '"';
        }
        // Fix: Properly escape the entire attributes string
        echo '<img' . esc_attr($attributes) . ' />';
    }
    echo '<p> توجه فرمایید لندینگ پیج مورد نظر حتما منتشر شده و فعال باشد.<p/>';
    echo '</div>';

    echo '<div class="landin-help-section">';
    echo '<h3>مرحله دوم: افزودن صفحه به افزونه وردپرس</h3>';
    echo '<ul>';
    echo '<li>در وردپرس، از منوی سمت راست وارد <span class="bold">افزونه لندین</span> شوید و به تب <span class="bold">مدیریت صفحات</span> بروید.</li>';
    echo '<li>یک <span class="bold">نام انگلیسی</span> برای آدرس صفحه دلخواه خود وارد کنید. این نام در انتهای URL قرار می‌گیرد.</li>';
    echo '<li>فایل اسکریپت HTML که در مرحله قبل از پنل لندین دانلود کرده‌اید را انتخاب کنید.</li>';
    echo '<li>روی دکمه <span class="bold">بارگذاری</span> کلیک کنید.</li>';
    echo '</ul>';
    echo '</div>';

    echo '<div class="landin-help-section">';
    echo '<h3>تنظیمات اتصال</h3>';
    echo '<p>در تب <span class="bold">تنظیمات اتصال</span> می‌توانید <span class="bold">مسیر پایه</span> (Base Path) لندینگ‌پیج‌ها را تغییر دهید.</p>';
    echo '<p>مسیر پیش‌فرض <code>landings</code> است، که در آدرس به صورت زیر نمایش داده می‌شود:</p>';
    echo '<p><code>https://yourdomain.com/landings/slug</code> </p>';
    echo '<p>همچنین می‌توانید از <span class="bold">تاریخچه مسیرهای قبلی</span> خود استفاده کرده و در صورت نیاز به آن‌ها بازگردید.</p>';
    echo '</div>';

    echo '<div class="landin-help-section">';
    echo '<a href="https://app.landin.ir" target="_blank" class="landin-help-section-button">ساخت صفحه فرود</a>';
    echo '</div>';

    echo '</div>';
}

// رفع: ثبت قوانین بازنویسی هنگام init پلاگین و اطمینان از عملکرد همیشگی آنها
add_action('init', 'landin_register_rewrite_rules', 10);

// پاسخگویی برای افزودن متغیر landin_slug به کوئری
add_filter('query_vars', function ($vars) {
    $vars[] = 'landin_slug';
    return $vars;
});

// اطمینان از اینکه قوانین بازنویسی فقط در صورت نیاز flush شوند
add_action('admin_init', function () {
    // دریافت مقدار فعلی گزینه
    $landin_version = get_option('landin_plugin_version', '0');

    // اگر نسخه تغییر کرده یا هنوز وجود ندارد
    if (version_compare($landin_version, '1.0.2', '<')) {
        // Flush قوانین بازنویسی
        flush_rewrite_rules();

        // به‌روزرسانی گزینه نسخه
        update_option('landin_plugin_version', '1.0.2');
    }
});

add_filter('query_vars', function ($vars) {
    $vars[] = 'landin_slug';
    return $vars;
});

add_action('template_redirect', function () {
    $slug = get_query_var('landin_slug');
    if ($slug) {
        $upload_dir = wp_upload_dir();
        $settings = landin_get_settings();

        // Only check current base path
        $landing_dir = $upload_dir['basedir'] . '/' . $settings['landing_base_path'];
        $file_path = $landing_dir . '/' . $slug . '/index.html';

        if (file_exists($file_path)) {
            header('Content-Type: text/html; charset=utf-8');
            $wp_filesystem = landin_init_filesystem();
            // Use output buffering to safely output the HTML content
            ob_start();
            // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
            echo $wp_filesystem->get_contents($file_path);
            ob_end_flush();
            exit();
        } else {

            // Set 404 header and load standard WordPress 404 page
            global $wp_query;
            $wp_query->set_404();
            status_header(404);
            include(get_query_template('404'));
            exit();
        }
    }
});

register_activation_hook(__FILE__, function () {
    // ایجاد دایرکتوری لندینگ هنگام فعال‌سازی
    landin_get_upload_dir();

    // ثبت قانون بازنویسی ما
    landin_register_rewrite_rules();

    // Flush قوانین بازنویسی
    flush_rewrite_rules();

    // ذخیره نسخه فعلی
    update_option('landin_plugin_version', '1.0.2');
});

// حذف فایل‌های لندینگ پیج هنگام حذف پلاگین
function landin_uninstall_cleanup()
{
    $upload_dir = wp_upload_dir();
    $settings = landin_get_settings();
    $landing_dir = $upload_dir['basedir'] . '/' . $settings['landing_base_path'];

    // پاک کردن تمام پوشه‌ها و فایل‌ها در دایرکتوری لندینگ
    if (file_exists($landing_dir)) {
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator(
                $landing_dir,
                RecursiveDirectoryIterator::SKIP_DOTS
            ),
            RecursiveIteratorIterator::CHILD_FIRST
        );
        foreach ($files as $fileinfo) {
            $todo = $fileinfo->isDir() ? 'rmdir' : 'unlink';
            $todo($fileinfo->getRealPath());
        }
        $wp_filesystem = landin_init_filesystem();
        $wp_filesystem->rmdir($landing_dir, true);
    }

    // حذف گزینه نسخه پلاگین
    delete_option('landin_plugin_version');
    delete_option('landin_settings');

    // Flush قوانین بازنویسی
    flush_rewrite_rules();
}

register_uninstall_hook(__FILE__, 'landin_uninstall_cleanup');

register_deactivation_hook(__FILE__, function () {
    flush_rewrite_rules();
});

// افزودن یادآوری برای flush کردن قوانین بازنویسی پس از حذف یک لندینگ
add_action('admin_notices', function () {
    // Check if we're on the right admin page using WordPress functions
    $current_screen = get_current_screen();
    
    // Only proceed if we're on the landing manager page
    if ($current_screen && 
        $current_screen->id === 'toplevel_page_landin-landing-manager') {
        
        // Check for the deletion notification parameter
        if (isset($_GET['landin_deleted']) && 
            isset($_GET['_wpnonce']) && 
            wp_verify_nonce(sanitize_key($_GET['_wpnonce']), 'landin_deletion_notice')) {
            
            echo '<div class="notice notice-info is-dismissible"><p>لندینگ حذف شد. اگر با مشکل مواجه شدید، به تنظیمات پیوندهای یکتا بروید و ذخیره کنید تا قوانین بازنویسی به‌روز شوند.</p></div>';
        }
    }
});
